@@ -1,14 +1,14 @@
 ;;; tempel.el --- Tempo templates/snippets with in-buffer field editing -*- lexical-binding: t -*-
 
-;; Copyright (C) 2022-2023 Free Software Foundation, Inc.
+;; Copyright (C) 2022-2024 Free Software Foundation, Inc.
 
 ;; Author: Daniel Mendler <mail@daniel-mendler.de>
 ;; Maintainer: Daniel Mendler <mail@daniel-mendler.de>
 ;; Created: 2022
-;; Version: 0.8
-;; Package-Requires: ((emacs "27.1") (compat "29.1.4.0"))
+;; Version: 1.1
+;; Package-Requires: ((emacs "27.1") (compat "29.1.4.4"))
 ;; Homepage: https://github.com/minad/tempel
-;; Keywords: abbrev, languages, tools, wp
+;; Keywords: abbrev, languages, tools, text
 
 ;; This file is part of GNU Emacs.
 
@@ -228,8 +228,9 @@ BEG and END are the boundaries of the modification."
     (let ((inhibit-modification-hooks nil)
           (tempel--inhibit-hooks t))
       (cond
-       ;; Erase default before modification if at beginning or end
-       ((and (not after) (overlay-get ov 'tempel--default)
+       ;; Erase default text before modification when typing over it at the
+       ;; beginning or end. Deleting or editing inside preserves the text.
+       ((and (not after) (overlay-get ov 'tempel--default) (eq beg end)
              (or (= beg (overlay-start ov)) (= end (overlay-end ov))))
         (delete-region (overlay-start ov) (overlay-end ov)))
        ;; Update field after modification
@@ -493,7 +494,9 @@ This is meant to be a source in `tempel-template-sources'."
    (cl-loop
     for m in modes thereis
     (or (eq m #'fundamental-mode)
-        (derived-mode-p m)))
+        (derived-mode-p m)
+        (when-let ((remap (alist-get m (bound-and-true-p major-mode-remap-alist))))
+          (derived-mode-p remap))))
    (or (not (plist-member plist :when))
        (save-excursion
          (save-restriction
@@ -608,9 +611,7 @@ This is meant to be a source in `tempel-template-sources'."
   (when st
     (mapc #'delete-overlay (car st))
     (unless tempel--active
-      (setq minor-mode-overriding-map-alist
-            (delq (assq-delete-all 'tempel--active minor-mode-overriding-map-alist)
-                  minor-mode-overriding-map-alist)))))
+      (cl-callf2 assq-delete-all 'tempel--active minor-mode-overriding-map-alist))))
 
 (defun tempel-done ()
   "Template completion is done."
@@ -763,7 +764,8 @@ If called interactively, select a template with `completing-read'."
 (defun tempel--abbrev-hook (name template)
   "Abbreviation expansion hook for TEMPLATE with NAME."
   (tempel--delete-word name)
-  (tempel--insert template nil))
+  (tempel--insert template nil)
+  t)
 
 ;;;###autoload
 (define-minor-mode tempel-abbrev-mode
@@ -788,8 +790,9 @@ If called interactively, select a template with `completing-read'."
                         abbrev-minor-mode-table-alist)))))
 
 ;;;###autoload
-(define-globalized-minor-mode global-tempel-abbrev-mode tempel-abbrev-mode
-  tempel--abbrev-on :group 'tempel)
+(define-globalized-minor-mode global-tempel-abbrev-mode
+  tempel-abbrev-mode tempel--abbrev-on
+  :group 'tempel)
 
 (defun tempel--abbrev-on ()
   "Enable abbrev mode locally."
